Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CustomData ¶
type CustomModel ¶
type CustomModel struct {
Program int
Data *CustomData
InitFn *golua.LFunction
UpdateFn *golua.LFunction
ViewFn *golua.LFunction
State *golua.LState
Item *TeaItem
CMDBuild cmdBuilder
MSGBuild msgBuilder
}
Data is double nested so the pointer can be modified even though the recievers are not pointers
func NewCustomModel ¶
func (CustomModel) Init ¶
func (m CustomModel) Init() tea.Cmd
func (CustomModel) View ¶
func (m CustomModel) View() string
type TeaItem ¶
type TeaItem struct {
LuaModel *golua.LTable
FnInit *golua.LFunction
FnUpdate *golua.LFunction
FnView *golua.LFunction
Msg *tea.Msg
Cmds []tea.Cmd
KeyBindings []*key.Binding
Spinners map[int]*spinner.Model
TextAreas []*textarea.Model
TextInputs []*textinput.Model
Cursors []*cursor.Model
FilePickers []*filepicker.Model
Lists []*list.Model
ListDelegates []*list.DefaultDelegate
Paginators []*paginator.Model
ProgressBars []*progress.Model
StopWatches map[int]*stopwatch.Model
Timers map[int]*timer.Model
Tables []*table.Model
Viewports []*viewport.Model
Customs []*CustomModel
Helps []*help.Model
Images []*teaimage.Model
StatusBars []*statusbar.Model
}
Click to show internal directories.
Click to hide internal directories.